Crate harn_stdlib

Crate harn_stdlib 

Canonical embedded Harn standard library source catalog.

This crate intentionally contains only static source strings so runtime and static tooling crates can share the same stdlib modules without depending on each other.

Structs

StdlibEntrypointModule
StdlibPromptAsset
StdlibPublicFunction
StdlibSource

Constants

STDLIB_PROMPT_ASSETS
STDLIB_SOURCES

Functions

entrypoint_modules
get_stdlib_prompt_asset
get_stdlib_source
public_functions_for_module