Crate harn_stdlib

Crate harn_stdlib 

Canonical embedded Harn standard library source catalog.

This crate intentionally contains only static source strings so runtime and static tooling crates can share the same stdlib modules without depending on each other.

Structs

StdlibSource

Constants

STDLIB_SOURCES

Functions

get_stdlib_source